Struct network::protocols::health_checker::HealthCheckerNetworkSender[][src]

pub struct HealthCheckerNetworkSender { /* fields omitted */ }
The interface from HealthChecker to Networking layer.

This is a thin wrapper around a NetworkSender<HealthCheckerMsg>, so it is easy to clone and send off to a separate task. For example, the rpc requests return Futures that encapsulate the whole flow, from sending the request to remote, to finally receiving the response and deserializing. It therefore makes the most sense to make the rpc call on a separate async task, which requires the HealthCheckerNetworkSender to be Clone and Send.

Implementations